summaryrefslogtreecommitdiff
path: root/test/unit/t_amount.cc
diff options
context:
space:
mode:
authorJohn Wiegley <johnw@newartisans.com>2010-06-01 17:44:28 -0400
committerJohn Wiegley <johnw@newartisans.com>2010-06-01 17:56:41 -0400
commit038c24357e85b3b33460f3b8d41b1ef4ab0ed901 (patch)
tree1c0b5770843a7dae763f5f0264219a060e34fb96 /test/unit/t_amount.cc
parentd513c71236b3e91bb999158829250e7194a9d56e (diff)
downloadfork-ledger-038c24357e85b3b33460f3b8d41b1ef4ab0ed901.tar.gz
fork-ledger-038c24357e85b3b33460f3b8d41b1ef4ab0ed901.tar.bz2
fork-ledger-038c24357e85b3b33460f3b8d41b1ef4ab0ed901.zip
Changed --european option to --decimal-comma
Fixes #211 / 1736ACA5-5DE6-4826-AEB4-DB5B2A2217AC
Diffstat (limited to 'test/unit/t_amount.cc')
-rw-r--r--test/unit/t_amount.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/unit/t_amount.cc b/test/unit/t_amount.cc
index 2c91ee98..63d82675 100644
--- a/test/unit/t_amount.cc
+++ b/test/unit/t_amount.cc
@@ -64,9 +64,9 @@ void AmountTestCase::testParser()
x16.parse("$2000,00");
assertEqual(string("$2.000,00"), x16.to_string());
- // Since European-ness is an additive quality, we must switch back
- // to American-ness manually
- x15.commodity().drop_flags(COMMODITY_STYLE_EUROPEAN);
+ // Since use of a decimal-comma is an additive quality, we must switch back
+ // to decimal-period manually.
+ x15.commodity().drop_flags(COMMODITY_STYLE_DECIMAL_COMMA);
amount_t x17("$1,000,000.00"); // parsing this switches back to American